
	*********************************************************************
	**********    				Spatial CoC				   **************
	**********			Estimations - Simulations		   **************
	********** 				  Table 8, Table 9  		   **************
	**********					JAERE FINAL				   **************
	*********************************************************************
	*********************************************************************

	clear 
	capture log close 
	set scrollbufsize 500000
	set matsize 10000
	version 12
	**********************************************************************

	sca drop _all

	**********************************************************************
	********************** Spatial Weights *******************************
	**********************************************************************

	use spatialfish_small.dta, clear

	************************************
	keep countrycode

	rename countrycode iso_d
	sort iso_d
	save dist_count_merge_isod.dta, replace

	******		LAST SORT 		********
	rename iso_d iso_o
	sort iso_o
	save dist_count_merge_isoo.dta, replace

	************************************


	*********ready to merge*************
	merge iso_o using dist_cepii.dta
	drop if _merge==2
	drop _merge

	sort iso_d
	merge iso_d using dist_count_merge_isod.dta
	tab _merge
	drop if _merge==1

	sort iso_o 
	keep  iso_o iso_d dist
	sort iso_o iso_d
	reshape wide dist, i(iso_o) j(iso_d) string

	#delimit
	foreach z of varlist dist* {;
	 replace `z'=`z'/1000;
	 replace `z'=1/exp(3*`z');			/* exponential distance  */
	};
	#delimit cr


	#delimit;
	mkmat  dist*, matrix(DIST) rownames(iso_o);
	#delimit cr

	local i=1
	local nobs=_N								/* **** loop to get 0 in the diagonal elements of DIST Matrix **** */
	while `i' <=`nobs'{
		
		local j=1
		while `j' <=`nobs'{
			if `i'==`j' {
			matrix DIST[`i',`j']=0
					}
			local j=`j'+1 	
			}

	local i=`i'+1
	}								
	***

	gen id= _n
	keep id


	************************************
	******** Defining Matrices *********
	************************************

	svmat DIST
	spmat dta W DIST*, normalize(min) id(id)  replace
	spmat getmatrix W WMAT
	mata{
	st_matrix("DIST", WMAT)
	}
	preserve
	drop _all
	svmat DIST
	save W.dta, replace 
	spatwmat using W.dta, name (WSPATIAL)
	matrix W = DIST
	restore
	drop DIST*

	****************************************************
	****************************************************
	***												****
	***  		Identification Strategy	 			****
	***												****
	****************************************************
	****************************************************

	use spatialfish_small.dta, clear

	************
	gen id= _n
	************

	*****************************************************
	*****		Defining Compliance Variable       ******
	*****************************************************

	gen compliance = all_mean


	*****************************************************
	*****	  Generating Spatial Lags of X 	       ******
	*****************************************************


	spmat lag x_gdp W gdp
	spmat lag x_distance W distance
	spmat lag x_gov W gov
	spmat lag x_competition W competition
	spmat lag x_export W export
	spmat lag x_eezcatch W eezcatch
	spmat lag x_bio W bio
	spmat lag x_treaty W treaty


	*****************************************************
	*****************************************************

	*****************************************************
	*****	  0. Step: Defining Control 	       ******
	*****************************************************

	local controls gdp distance gov competition bio  export eezcatch treaty 

	local spatcontrols x_gdp x_distance x_gov x_competition x_bio x_export x_eezcatch x_treaty 

	*****************************************************
	*****	1.Step: Spatial Durbin Model 	       ******
	*****************************************************

	spreg ml compliance `controls' `spatcontrols', id(id) dlmat(W) noconst

	*****************************************************
	*****	2.Step: Model interpretation - LeSage  ******
	*****************************************************

	mat result1=J(8,3,0)
	mat bb=e(b)
	sca rho=bb[1,17]

	local counter=1

	while `counter' <= 8 {
	sca counter=`counter'+8


	sca b1=bb[1,`counter']
	sca b2=bb[1,counter]
	sca nn=_N

	mat ii=J(nn,1,1)  
	mat IN=I(nn)
	mat V=inv(IN-rho*W)*(b1*IN+b2*W)

	mat adirect=trace(V)/nn
	mat atotal=ii'*V*ii/nn
	sca aindirect=atotal[1,1]-adirect[1,1]

	mat VSPM=inv(IN-rho*W)					/* spatial multiplier  */
	mat SPM=ii'*VSPM*ii/nn

	***** Inserting in Result Matrix *****


	mat result1[`counter',1]=adirect[1,1]
	mat result1[`counter',2]=aindirect
	mat result1[`counter',3]=atotal[1,1]

	*****
	local counter=(`counter'+1)
	}	 

	#delimit;
	matrix colnames result1 = DIREC INDIRECT TOTAL;
	#delimit cr

***************************************************************************
**** 	3.Step:	Simulation to get inferential statistics (Table 8 & 9) ****
***************************************************************************

set seed 1010101
local reps=10000

mat result=J(`reps',32,0)
mat yresult=J(`reps',15,0)
mat total_effectrich_t=J(`reps',51,0)
mat sdirect_effectrich_t=J(`reps',51,0)
mat sindirect_effectrich_t=J(`reps',51,0)
mat bbsimtest=J(`reps',8,0)
mat bb2simtest=J(`reps',8,0)
mat rhosimtest=J(`reps',8,0)
mat bb=e(b)
mat cov=e(V)

sum gdp,d
sca rich = r(p75)
sca poor = r(p25)
sca middle= r(p50)
sum gdp if gdp<poor
sca obspoor = r(N)
sum gdp if gdp>rich
sca obsrich = r(N)
sum gdp if gdp<middle
sca obsmiddle = r(N)

local totround=1
local resu=0
while `totround' <= 8 {
sca totround=`totround'+8

local rep=1							
while `rep' <=`reps'{

mat chol=cholesky(cov)
gen randn=rnormal()
mkmat randn, matrix(lrandn)
mat randn=lrandn[1..18,1]
mat randn=randn'
*mat randn=J(1,9,rnormal())
drop randn
mat bbsim=chol*randn'+bb'

***********************************************************************
**** Step 3.1: Direct - Indirect effects by change in X	 (Table 8) ****
***********************************************************************
sca rhosim=bbsim[17,1]
mat rhosimtest[`rep',`totround']=rhosim
sca b1sim=bbsim[`totround',1]
mat bbsimtest[`rep',`totround']=b1sim
sca b2sim=bbsim[totround,1]
mat bb2simtest[`rep',`totround']=b2sim
sca nn=_N

mat ii=J(nn,1,1)  
mat IN=I(nn)
mat V=inv(IN-rhosim*W)*(b1sim*IN+b2sim*W)

mat adirect=trace(V)/nn
mat atotal=ii'*V*ii/nn
sca aindirect=atotal[1,1]-adirect[1,1]


***** Inserting in Result Matrix *****


mat result[`rep',1+`resu']=adirect[1,1]
mat result[`rep',2+`resu']=aindirect
mat result[`rep',3+`resu']=atotal[1,1]
mat result[`rep',4+`resu']=rhosim

**********************************************************

******************************************************************************
***** Step 3.2: Effect of Change in y to all other countries  (Table 9)  *****
******************************************************************************

mat yeffect=inv(IN-rhosim*W)
svmat yeffect

#delimit;
foreach z in yeffect1 yeffect2 yeffect3 yeffect4 yeffect5 yeffect6 yeffect7 yeffect8 yeffect9 yeffect10 yeffect11 yeffect12 yeffect13 yeffect14	yeffect15 yeffect16
	  	 yeffect17 yeffect18 yeffect19 yeffect20 yeffect21 yeffect22 yeffect23 yeffect24 yeffect25 yeffect26 yeffect27 yeffect28 yeffect29 yeffect30 yeffect31
		 yeffect32 yeffect33 yeffect34 yeffect35 yeffect36 yeffect37 yeffect38 yeffect39 yeffect40 yeffect41 yeffect42 yeffect43 yeffect44 yeffect45 yeffect46
 		 yeffect47 yeffect48 yeffect49 yeffect50 yeffect51{;
quietly egen tot_`z' = total(`z');
};
#delimit cr

mkmat tot_yeffect*, matrix(TOTY)
mat DITOTY = vecdiag(TOTY)
mat TOTALYEFFECT=TOTY'
svmat TOTALYEFFECT

mat DIY = vecdiag(yeffect)
mat DIRECTYEFFECT=DIY'
svmat DIRECTYEFFECT

quietly gen INDIRECTYEFFECT= TOTALYEFFECT1-DIRECTYEFFECT1
quietly gen SDIRECTYEFFECT= DIRECTYEFFECT1-1

qui replace TOTALYEFFECT1=. if rhosim>=0.97 | rhosim<=-0.97 | rhosim==0
qui replace INDIRECTYEFFECT=. if rhosim>=0.97 | rhosim<=-0.97 | rhosim==0
qui replace SDIRECTYEFFECT=. if rhosim>=0.97 | rhosim<=-0.97 | rhosim==0

************ Rich/Poor/Average Spatial effects  **************

****  Rich  ****

quietly egen effect= total(TOTALYEFFECT1) if gdp>rich
quietly egen total_effectrich = mean(effect)
quietly replace total_effectrich = total_effectrich/obsrich
sca total_effectrich=total_effectrich
drop effect

quietly egen effect= total(SDIRECTYEFFECT) if gdp>rich
quietly egen sdirect_effectrich = mean(effect)
quietly replace sdirect_effectrich = sdirect_effectrich/obsrich
sca sdirect_effectrich=sdirect_effectrich
drop effect

quietly egen effect= total(INDIRECTYEFFECT) if gdp>rich
quietly egen sindirect_effectrich = mean(effect)
quietly replace sindirect_effectrich = sindirect_effectrich/obsrich
sca sindirect_effectrich=sindirect_effectrich
drop effect

****  Poor  ****

quietly egen effect= total(TOTALYEFFECT1) if gdp<poor
quietly egen total_effectpoor = mean(effect)
quietly replace total_effectpoor = total_effectpoor/obspoor
sca total_effectpoor=total_effectpoor
drop effect

quietly egen effect= total(SDIRECTYEFFECT) if gdp<poor
quietly egen sdirect_effectpoor = mean(effect)
quietly replace sdirect_effectpoor = sdirect_effectpoor/obspoor
sca sdirect_effectpoor=sdirect_effectpoor
drop effect

quietly egen effect= total(INDIRECTYEFFECT) if gdp<poor
quietly egen sindirect_effectpoor = mean(effect)
quietly replace sindirect_effectpoor = sindirect_effectpoor/obspoor
sca sindirect_effectpoor=sindirect_effectpoor
drop effect

****  Average  ****

quietly egen effect= total(TOTALYEFFECT1)
quietly egen total_effectav = mean(effect)
quietly replace total_effectav = total_effectav/51
sca total_effectav=total_effectav
drop effect

quietly egen effect= total(SDIRECTYEFFECT)
quietly egen sdirect_effectav = mean(effect)
quietly replace sdirect_effectav = sdirect_effectav/51
sca sdirect_effectav=sdirect_effectav
drop effect

quietly egen effect= total(INDIRECTYEFFECT)
quietly egen sindirect_effectav = mean(effect)
quietly replace sindirect_effectav = sindirect_effectav/51
sca sindirect_effectav=sindirect_effectav
drop effect

****  1&2 Quartile  *****

quietly egen effect= total(TOTALYEFFECT1) if gdp>middle
quietly egen total_rich_2quat = mean(effect)
quietly replace total_rich_2quat = total_rich_2quat/obsmiddle
sca total_rich_2quat=total_rich_2quat
drop effect

quietly egen effect= total(SDIRECTYEFFECT) if gdp>middle
quietly egen sdirect_rich_2quat = mean(effect)
quietly replace sdirect_rich_2quat = sdirect_rich_2quat/obsmiddle
sca sdirect_rich_2quat=sdirect_rich_2quat
drop effect

quietly egen effect= total(INDIRECTYEFFECT) if gdp>middle
quietly egen sindirect_rich_2quat = mean(effect)
quietly replace sindirect_rich_2quat = sindirect_rich_2quat/obsmiddle
sca sindirect_rich_2quat=sindirect_rich_2quat
drop effect

****  3&4 Quartile  ****

quietly egen effect= total(TOTALYEFFECT1) if gdp<=middle
quietly egen total_poor_2quat = mean(effect)
quietly replace total_poor_2quat = total_poor_2quat/(obsmiddle+1)
sca total_poor_2quat=total_poor_2quat
drop effect

quietly egen effect= total(SDIRECTYEFFECT) if gdp<=middle
quietly egen sdirect_poor_2quat = mean(effect)
quietly replace sdirect_poor_2quat = sdirect_poor_2quat/(obsmiddle+1)
sca sdirect_poor_2quat=sdirect_poor_2quat
drop effect

quietly egen effect= total(INDIRECTYEFFECT) if gdp<=middle
quietly egen sindirect_poor_2quat = mean(effect)
quietly replace sindirect_poor_2quat = sindirect_poor_2quat/(obsmiddle+1)
sca sindirect_poor_2quat=sindirect_poor_2quat
drop effect



***** Inserting in Result Matrix *****

mat yresult[`rep',1]=total_effectav
mat yresult[`rep',2]=total_effectrich
mat yresult[`rep',3]=total_effectpoor

mat yresult[`rep',4]=sdirect_effectav
mat yresult[`rep',5]=sdirect_effectrich
mat yresult[`rep',6]=sdirect_effectpoor

mat yresult[`rep',7]=sindirect_effectav
mat yresult[`rep',8]=sindirect_effectrich
mat yresult[`rep',9]=sindirect_effectpoor

mat yresult[`rep',10]=total_rich_2quat
mat yresult[`rep',11]=total_poor_2quat

mat yresult[`rep',12]=sdirect_rich_2quat
mat yresult[`rep',13]=sdirect_poor_2quat

mat yresult[`rep',14]=sindirect_rich_2quat
mat yresult[`rep',15]=sindirect_poor_2quat

*****************************************


di in red `rep'
local rep=(`rep'+1)
keep country gdp
}
di in blue `totround'
local resu=(`resu'+4)
local totround=(`totround'+1)
}	 
******************************************************

**************************************************************
*****  Step 4: Calculating inferential statisitics	   *******
**************************************************************


**************************************************************************
*****  Step 4.1: Calculating inferential statisitics (Table 8)	   *******
**************************************************************************
drop _all

******************************

local number=1
local mats=0
local matso=0

mat margfx=J(8,18,0)
mat margfx2=J(8,9,0)

while `number'<=8 {
drop _all
svmat result
rename result1 direct1
rename result2 indirect1
rename result3 total1
rename result4 rhotest1
rename result5 direct2
rename result6 indirect2
rename result7 total2
rename result8 rhotest2
rename result9 direct3
rename result10 indirect3
rename result11 total3
rename result12 rhotest3
rename result13 direct4
rename result14 indirect4
rename result15 total4
rename result16 rhotest4
rename result17 direct5
rename result18 indirect5
rename result19 total5
rename result20 rhotest5
rename result21 direct6
rename result22 indirect6
rename result23 total6
rename result24 rhotest6
rename result25 direct7
rename result26 indirect7
rename result27 total7
rename result28 rhotest7
rename result29 direct8
rename result30 indirect8
rename result31 total8
rename result32 rhotest8

drop if rhotest`number'==0
drop if rhotest`number'>=0.97	  
drop if rhotest`number'<=-0.97   

*********************************

egen mdirect`number'=mean(direct`number')
sca mdirect`number'=mdirect`number'
egen mindirect`number'=mean(indirect`number')
sca mindirect`number'=mindirect`number'
egen mtotal`number'=mean(total`number')
sca mtotal`number'=mtotal`number'


egen sddirect`number'=sd(direct`number')
sca sddirect`number'=sddirect`number'
egen sdindirect`number'=sd(indirect`number')
sca sdindirect`number'=sdindirect`number'
egen sdtotal`number'=sd(total`number')
sca sdtotal`number'=sdtotal`number'

sca t_val_direct`number'=mdirect`number'/sddirect`number'
sca t_val_indirect`number'=mindirect`number'/sdindirect`number'
sca t_val_total`number'=mtotal`number'/sdtotal`number'

sca df_r=(nn-e(df_m))

sca p_val_direct`number'=2*ttail(df_r,abs(t_val_direct`number'))
sca p_val_indirect`number'=2*ttail(df_r,abs(t_val_indirect`number'))
sca p_val_total`number'=2*ttail(df_r,abs(t_val_total`number'))

sca ci_low_direct`number'=mdirect`number' - invttail(df_r,0.025)*sddirect`number'
sca ci_high_direct`number'=mdirect`number' + invttail(df_r,0.025)*sddirect`number'
sca ci_low_indirect`number'=mindirect`number' - invttail(df_r,0.025)*sdindirect`number'
sca ci_high_indirect`number'=mindirect`number' + invttail(df_r,0.025)*sdindirect`number'
sca ci_low_total`number'=mtotal`number' - invttail(df_r,0.025)*sdtotal`number'
sca ci_high_total`number'=mtotal`number' + invttail(df_r,0.025)*sdtotal`number'

******************************************************
******************************************************

mat margfx[`number',`mats'+1]= mdirect`number'
mat margfx[`number',`mats'+2]= sddirect`number'
mat margfx[`number',`mats'+3]= t_val_direct`number'
mat margfx[`number',`mats'+4]= p_val_direct`number'
mat margfx[`number',`mats'+5]= ci_low_direct`number'
mat margfx[`number',`mats'+6]= ci_high_direct`number'
mat margfx[`number',`mats'+7]= mindirect`number'
mat margfx[`number',`mats'+8]= sdindirect`number'
mat margfx[`number',`mats'+9]= t_val_indirect`number'
mat margfx[`number',`mats'+10]= p_val_indirect`number'
mat margfx[`number',`mats'+11]= ci_low_indirect`number'
mat margfx[`number',`mats'+12]= ci_high_indirect`number'
mat margfx[`number',`mats'+13]= mtotal`number'
mat margfx[`number',`mats'+14]= sdtotal`number'
mat margfx[`number',`mats'+15]= t_val_total`number'
mat margfx[`number',`mats'+16]= p_val_total`number'
mat margfx[`number',`mats'+17]= ci_low_total`number'
mat margfx[`number',`mats'+18]= ci_high_total`number'


mat margfx2[`number',`matso'+1]= mdirect`number'
mat margfx2[`number',`matso'+2]= sddirect`number'
mat margfx2[`number',`matso'+3]= p_val_direct`number'
mat margfx2[`number',`matso'+4]= mindirect`number'
mat margfx2[`number',`matso'+5]= sdindirect`number'
mat margfx2[`number',`matso'+6]= p_val_indirect`number'
mat margfx2[`number',`matso'+7]= mtotal`number'
mat margfx2[`number',`matso'+8]= sdtotal`number'
mat margfx2[`number',`matso'+9]= p_val_total`number'

******************************************************
local number=`number'+1
}

******************************************************


**************************************************************************
*****  Step 4.1: Calculating inferential statisitics (Table 9)	   *******
**************************************************************************
drop _all

mat margfx3=J(5,9,0)

svmat yresult
#delimit;
drop if yresult1==0 | yresult2==0 | yresult3==0 | yresult4==0| yresult5==0 | yresult6==0 | yresult7==0 | yresult8==0 
| yresult9==0 | yresult10==0 | yresult11==0 | yresult12==0 | yresult13==0 | yresult14==0 | yresult15==0 ;
# delimit cr

rename yresult1 total_effectav
rename yresult2 total_effectrich
rename yresult3 total_effectpoor
rename yresult4 sdirect_effectav
rename yresult5 sdirect_effectrich
rename yresult6 sdirect_effectpoor
rename yresult7 sindirect_effectav
rename yresult8 sindirect_effectrich
rename yresult9 sindirect_effectpoor
rename yresult10 total_rich_2quat
rename yresult11 total_poor_2quat
rename yresult12 sdirect_rich_2quat
rename yresult13 sdirect_poor_2quat
rename yresult14 sindirect_rich_2quat
rename yresult15 sindirect_poor_2quat

egen mtotal_effectav 		=	mean(total_effectav	)	
egen mtotal_effectrich		=	mean(total_effectrich)	
egen mtotal_effectpoor		=	mean(total_effectpoor)	
egen msdirect_effectav		=	mean(sdirect_effectav)	
egen msdirect_effectrich	=	mean(sdirect_effectrich)	
egen msdirect_effectpoor	=	mean(sdirect_effectpoor)	
egen msindirect_effectav	=	mean(sindirect_effectav)	
egen msindirect_effectrich	=	mean(sindirect_effectrich)	
egen msindirect_effectpoor	=	mean(sindirect_effectpoor)	
egen mtotal_rich_2quat		=	mean(total_rich_2quat)	
egen mtotal_poor_2quat		=	mean(total_poor_2quat)	
egen msdirect_rich_2quat	=	mean(sdirect_rich_2quat	)	
egen msdirect_poor_2quat	=	mean(sdirect_poor_2quat	)	
egen msindirect_rich_2quat	=	mean(sindirect_rich_2quat)	
egen msindirect_poor_2quat	=	mean(sindirect_poor_2quat)	
									
sca mtotal_effectav			=	mtotal_effectav				
sca mtotal_effectrich		=	mtotal_effectrich				
sca mtotal_effectpoor		=	mtotal_effectpoor				
sca msdirect_effectav		=	msdirect_effectav				
sca msdirect_effectrich		=	msdirect_effectrich				
sca msdirect_effectpoor		=	msdirect_effectpoor				
sca msindirect_effectav		=	msindirect_effectav				
sca msindirect_effectrich	=	msindirect_effectrich				
sca msindirect_effectpoor	=	msindirect_effectpoor				
sca mtotal_rich_2quat		=	mtotal_rich_2quat				
sca mtotal_poor_2quat		=	mtotal_poor_2quat				
sca msdirect_rich_2quat		=	msdirect_rich_2quat				
sca msdirect_poor_2quat		=	msdirect_poor_2quat				
sca msindirect_rich_2quat	=	msindirect_rich_2quat				
sca msindirect_poor_2quat	=	msindirect_poor_2quat				
									
									
egen sdtotal_effectav		=	sd(total_effectav)	
egen sdtotal_effectrich		=	sd(total_effectrich)	
egen sdtotal_effectpoor		=	sd(total_effectpoor)	
egen sdsdirect_effectav		=	sd(sdirect_effectav)	
egen sdsdirect_effectrich	=	sd(sdirect_effectrich)	
egen sdsdirect_effectpoor	=	sd(sdirect_effectpoor)	
egen sdsindirect_effectav	=	sd(sindirect_effectav)	
egen sdsindirect_effectrich	=	sd(sindirect_effectrich)	
egen sdsindirect_effectpoor	=	sd(sindirect_effectpoor)	
egen sdtotal_rich_2quat		=	sd(total_rich_2quat)	
egen sdtotal_poor_2quat		=	sd(total_poor_2quat)	
egen sdsdirect_rich_2quat	=	sd(sdirect_rich_2quat)	
egen sdsdirect_poor_2quat	=	sd(sdirect_poor_2quat)	
egen sdsindirect_rich_2quat	=	sd(sindirect_rich_2quat)	
egen sdsindirect_poor_2quat	=	sd(sindirect_poor_2quat)	
									
sca sdtotal_effectav		=	sdtotal_effectav				
sca sdtotal_effectrich		=	sdtotal_effectrich				
sca sdtotal_effectpoor		=	sdtotal_effectpoor				
sca sdsdirect_effectav		=	sdsdirect_effectav				
sca sdsdirect_effectrich	=	sdsdirect_effectrich				
sca sdsdirect_effectpoor	=	sdsdirect_effectpoor				
sca sdsindirect_effectav	=	sdsindirect_effectav				
sca sdsindirect_effectrich	=	sdsindirect_effectrich				
sca sdsindirect_effectpoor	=	sdsindirect_effectpoor				
sca sdtotal_rich_2quat		=	sdtotal_rich_2quat				
sca sdtotal_poor_2quat		=	sdtotal_poor_2quat				
sca sdsdirect_rich_2quat	=	sdsdirect_rich_2quat				
sca sdsdirect_poor_2quat	=	sdsdirect_poor_2quat				
sca sdsindirect_rich_2quat	=	sdsindirect_rich_2quat				
sca sdsindirect_poor_2quat	=	sdsindirect_poor_2quat				
									
sca	t_val_total_effectav		=	mtotal_effectav/sdtotal_effectav	
sca	t_val_total_effectrich		=	mtotal_effectrich/sdtotal_effectrich	
sca	t_val_total_effectpoor		=	mtotal_effectpoor/sdtotal_effectpoor	
sca	t_val_sdirect_effectav		=	msdirect_effectav/sdsdirect_effectav	
sca	t_val_sdirect_effectrich	=	msdirect_effectrich/sdsdirect_effectrich	
sca	t_val_sdirect_effectpoor	=	msdirect_effectpoor/sdsdirect_effectpoor	
sca	t_val_sindirect_effectav	=	msindirect_effectav/sdsindirect_effectav	
sca	t_val_sindirect_effectrich	=	msindirect_effectrich/sdsindirect_effectrich	
sca	t_val_sindirect_effectpoor	=	msindirect_effectpoor/sdsindirect_effectpoor	
sca	t_val_total_rich_2quat		=	mtotal_rich_2quat/sdtotal_rich_2quat	
sca	t_val_total_poor_2quat		=	mtotal_poor_2quat/sdtotal_poor_2quat	
sca	t_val_sdirect_rich_2quat	=	msdirect_rich_2quat/sdsdirect_rich_2quat	
sca	t_val_sdirect_poor_2quat	=	msdirect_poor_2quat/sdsdirect_poor_2quat	
sca	t_val_sindirect_rich_2quat	=	msindirect_rich_2quat/sdsindirect_rich_2quat	
sca	t_val_sindirect_poor_2quat	=	msindirect_poor_2quat/sdsindirect_poor_2quat	
		
sca df_r=(nn-e(df_m))
		
sca p_val_total_effectav		=	2*ttail(df_r,abs(t_val_total_effectav))			
sca	p_val_total_effectrich		=	2*ttail(df_r,abs(t_val_total_effectrich))			
sca	p_val_total_effectpoor		=	2*ttail(df_r,abs(t_val_total_effectpoor))			
sca	p_val_sdirect_effectav		=	2*ttail(df_r,abs(t_val_sdirect_effectav))			
sca	p_val_sdirect_effectrich	=	2*ttail(df_r,abs(t_val_sdirect_effectrich))			
sca	p_val_sdirect_effectpoor	=	2*ttail(df_r,abs(t_val_sdirect_effectpoor))			
sca	p_val_sindirect_effectav	=	2*ttail(df_r,abs(t_val_sindirect_effectav))			
sca	p_val_sindirect_effectrich	=	2*ttail(df_r,abs(t_val_sindirect_effectrich))			
sca	p_val_sindirect_effectpoor	=	2*ttail(df_r,abs(t_val_sindirect_effectpoor))			
sca	p_val_total_rich_2quat		=	2*ttail(df_r,abs(t_val_total_rich_2quat))			
sca	p_val_total_poor_2quat		=	2*ttail(df_r,abs(t_val_total_poor_2quat))			
sca	p_val_sdirect_rich_2quat	=	2*ttail(df_r,abs(t_val_sdirect_rich_2quat))			
sca	p_val_sdirect_poor_2quat	=	2*ttail(df_r,abs(t_val_sdirect_poor_2quat))			
sca	p_val_sindirect_rich_2quat	=	2*ttail(df_r,abs(t_val_sindirect_rich_2quat))			
sca	p_val_sindirect_poor_2quat	=	2*ttail(df_r,abs(t_val_sindirect_poor_2quat))			
									
sca ci_low_total_effectav		=	mtotal_effectav			- invttail(df_r,0.025)*sdtotal_effectav
sca ci_low_total_effectrich		=	mtotal_effectrich		- invttail(df_r,0.025)*sdtotal_effectrich
sca ci_low_total_effectpoor		=	mtotal_effectpoor		- invttail(df_r,0.025)*sdtotal_effectpoor
sca ci_low_sdirect_effectav		=	msdirect_effectav		- invttail(df_r,0.025)*sdsdirect_effectav
sca ci_low_sdirect_effectrich	=	msdirect_effectrich		- invttail(df_r,0.025)*sdsdirect_effectrich
sca ci_low_sdirect_effectpoor	=	msdirect_effectpoor		- invttail(df_r,0.025)*sdsdirect_effectpoor
sca ci_low_sindirect_effectav	=	msindirect_effectav		- invttail(df_r,0.025)*sdsindirect_effectav
sca ci_low_sindirect_effectrich	=	msindirect_effectrich	- invttail(df_r,0.025)*sdsindirect_effectrich
sca ci_low_sindirect_effectpoor	=	msindirect_effectpoor	- invttail(df_r,0.025)*sdsindirect_effectpoor
sca ci_low_total_rich_2quat		=	mtotal_rich_2quat		- invttail(df_r,0.025)*sdtotal_rich_2quat
sca ci_low_total_poor_2quat		=	mtotal_poor_2quat		- invttail(df_r,0.025)*sdtotal_poor_2quat
sca ci_low_sdirect_rich_2quat	=	msdirect_rich_2quat		- invttail(df_r,0.025)*sdsdirect_rich_2quat
sca ci_low_sdirect_poor_2quat	=	msdirect_poor_2quat		- invttail(df_r,0.025)*sdsdirect_poor_2quat
sca ci_low_sindirect_rich_2quat	=	msindirect_rich_2quat	- invttail(df_r,0.025)*sdsindirect_rich_2quat
sca ci_low_sindirect_poor_2quat	=	msindirect_poor_2quat	- invttail(df_r,0.025)*sdsindirect_poor_2quat
									
sca ci_high_total_effectav			=	mtotal_effectav			+	invttail(df_r,0.025)*sdtotal_effectav
sca ci_high_total_effectrich		=	mtotal_effectrich		+	invttail(df_r,0.025)*sdtotal_effectrich
sca ci_high_total_effectpoor		=	mtotal_effectpoor		+	invttail(df_r,0.025)*sdtotal_effectpoor
sca ci_high_sdirect_effectav		=	msdirect_effectav		+	invttail(df_r,0.025)*sdsdirect_effectav
sca ci_high_sdirect_effectrich		=	msdirect_effectrich		+	invttail(df_r,0.025)*sdsdirect_effectrich
sca ci_high_sdirect_effectpoor		=	msdirect_effectpoor		+	invttail(df_r,0.025)*sdsdirect_effectpoor
sca ci_high_sindirect_effectav		=	msindirect_effectav		+	invttail(df_r,0.025)*sdsindirect_effectav
sca ci_high_sindirect_effectrich	=	msindirect_effectrich	+	invttail(df_r,0.025)*sdsindirect_effectrich
sca ci_high_sindirect_effectpoor	=	msindirect_effectpoor	+	invttail(df_r,0.025)*sdsindirect_effectpoor
sca ci_high_total_rich_2quat		=	mtotal_rich_2quat		+	invttail(df_r,0.025)*sdtotal_rich_2quat
sca ci_high_total_poor_2quat		=	mtotal_poor_2quat		+	invttail(df_r,0.025)*sdtotal_poor_2quat
sca ci_high_sdirect_rich_2quat		=	msdirect_rich_2quat		+	invttail(df_r,0.025)*sdsdirect_rich_2quat
sca ci_high_sdirect_poor_2quat		=	msdirect_poor_2quat		+	invttail(df_r,0.025)*sdsdirect_poor_2quat
sca ci_high_sindirect_rich_2quat	=	msindirect_rich_2quat	+	invttail(df_r,0.025)*sdsindirect_rich_2quat
sca ci_high_sindirect_poor_2quat	=	msindirect_poor_2quat	+	invttail(df_r,0.025)*sdsindirect_poor_2quat

local number=1
local matsoo=0
mat margfx3[`number',`matso'+1]= msdirect_effectav
mat margfx3[`number',`matso'+2]= sdsdirect_effectav
mat margfx3[`number',`matso'+3]= p_val_sdirect_effectav
mat margfx3[`number',`matso'+4]= msindirect_effectav
mat margfx3[`number',`matso'+5]= sdsindirect_effectav
mat margfx3[`number',`matso'+6]= p_val_sindirect_effectav
mat margfx3[`number',`matso'+7]= mtotal_effectav
mat margfx3[`number',`matso'+8]= sdtotal_effectav
mat margfx3[`number',`matso'+9]= p_val_total_effectav
local number=`number'+1
local matsoo=0
mat margfx3[`number',`matso'+1]= msdirect_effectrich
mat margfx3[`number',`matso'+2]= sdsdirect_effectrich
mat margfx3[`number',`matso'+3]= p_val_sdirect_effectrich
mat margfx3[`number',`matso'+4]= msindirect_effectrich
mat margfx3[`number',`matso'+5]= sdsindirect_effectrich
mat margfx3[`number',`matso'+6]= p_val_sindirect_effectrich
mat margfx3[`number',`matso'+7]= mtotal_effectrich
mat margfx3[`number',`matso'+8]= sdtotal_effectrich
mat margfx3[`number',`matso'+9]= p_val_total_effectrich
local number=`number'+1
local matsoo=0
mat margfx3[`number',`matso'+1]= msdirect_effectpoor
mat margfx3[`number',`matso'+2]= sdsdirect_effectpoor
mat margfx3[`number',`matso'+3]= p_val_sdirect_effectpoor
mat margfx3[`number',`matso'+4]= msindirect_effectpoor
mat margfx3[`number',`matso'+5]= sdsindirect_effectpoor
mat margfx3[`number',`matso'+6]= p_val_sindirect_effectpoor
mat margfx3[`number',`matso'+7]= mtotal_effectpoor
mat margfx3[`number',`matso'+8]= sdtotal_effectpoor
mat margfx3[`number',`matso'+9]= p_val_total_effectpoor

local number=`number'+1
local matsoo=0
mat margfx3[`number',`matso'+1]= msdirect_rich_2quat
mat margfx3[`number',`matso'+2]= sdsdirect_rich_2quat
mat margfx3[`number',`matso'+3]= p_val_sdirect_rich_2quat
mat margfx3[`number',`matso'+4]= msindirect_rich_2quat
mat margfx3[`number',`matso'+5]= sdsindirect_rich_2quat
mat margfx3[`number',`matso'+6]= p_val_sindirect_rich_2quat
mat margfx3[`number',`matso'+7]= mtotal_rich_2quat
mat margfx3[`number',`matso'+8]= sdtotal_rich_2quat
mat margfx3[`number',`matso'+9]= p_val_total_rich_2quat
local number=`number'+1
local matsoo=0
mat margfx3[`number',`matso'+1]= msdirect_poor_2quat
mat margfx3[`number',`matso'+2]= sdsdirect_poor_2quat
mat margfx3[`number',`matso'+3]= p_val_sdirect_poor_2quat
mat margfx3[`number',`matso'+4]= msindirect_poor_2quat
mat margfx3[`number',`matso'+5]= sdsindirect_poor_2quat
mat margfx3[`number',`matso'+6]= p_val_sindirect_poor_2quat
mat margfx3[`number',`matso'+7]= mtotal_poor_2quat
mat margfx3[`number',`matso'+8]= sdtotal_poor_2quat
mat margfx3[`number',`matso'+9]= p_val_total_poor_2quat

**********************************************************
*****  Step 5: Formating of results matrices	   *******
**********************************************************

#delimit;
matrix colnames margfx = mdirect sddirect t_val_direct p_val_direc ci_low_direct ci_high_direct mindirect sdindirect t_val_indirect p_val_indirec ci_low_indirect ci_high_indirect
 mtotal sdtotal t_val_total p_val_total ci_low_total ci_high_total;
#delimit cr

#delimit;
matrix colnames margfx2 = DIREC DIREC_SD DIREC_P INDIRECT INDIRECT_SD INDIRECT_P TOTAL TOTAL_SD TOTAL_P;   /* *** RESULT TABLE 8 *** */
#delimit cr

#delimit;
matrix colnames margfx3 = DIREC DIREC_SD DIREC_P INDIRECT INDIRECT_SD INDIRECT_P TOTAL TOTAL_SD TOTAL_P;   /* *** RESULT TABLE 9 *** */
matrix rownames margfx3 = AVERAGE RICH POOR RICH_2 POOR_2;
#delimit cr

******************************************************
******************************************************
******************************************************
******************************************************

**********************************************************
*****    Step 6: *** RESULTS ***	  			   *******
**********************************************************

mat lis result1  /* Direct, indirect, total effect without simulation */
mat lis margfx2  /* *** RESULT TABLE 8 *** */
mat lis margfx3  /* *** RESULT TABLE 9 *** */

*******************************************************************
*******************************************************************
*********************     END     *********************************
*******************************************************************

