
*********************************************************************
**********    				Spatial CoC				   **************
**********			  	  	Estimations 			   **************
********** 			Table 2, Table 3, Table 4  		   **************
********** 			Table 5, Table 6, Table 7 		   **************
**********					JAERE FINAL				   **************
*********************************************************************
*********************************************************************

clear 
capture log close 
set scrollbufsize 500000
version 12

**********************************************************************
sca drop _all

**********************************************************************
********************** Spatial Weights *******************************
**********************************************************************

use spatialfish_small.dta, clear


************************************
keep countrycode

rename countrycode iso_d
sort iso_d
save dist_count_merge_isod.dta, replace

******		LAST SORT 		********
rename iso_d iso_o
sort iso_o
save dist_count_merge_isoo.dta, replace

************************************


*********ready to merge*************
merge iso_o using dist_cepii.dta
drop if _merge==2
drop _merge

sort iso_d
merge iso_d using dist_count_merge_isod.dta
tab _merge
drop if _merge==1

sort iso_o 
keep  iso_o iso_d dist
sort iso_o iso_d
reshape wide dist, i(iso_o) j(iso_d) string

preserve
#delimit
foreach z of varlist dist* {;
 replace `z'=`z'/1000;
 replace `z'=1/exp(3*`z');			/* exponential distance  */
};
*******************************************************************************************************
******************************************************************************************************* 
* replace `z'=1/(`z');				/* inverse distance 		--- *** Robustness Test TABLE 6 ***  */
*******************************************************************************************************
*******************************************************************************************************
* replace `z'=1/(`z')^2;			/* squared inverse distance --- *** Robustness Test TABLE 6 ***  */
*******************************************************************************************************
*******************************************************************************************************
#delimit cr


#delimit;
mkmat  dist*, matrix(DIST) rownames(iso_o);
#delimit cr

local i=1
local nobs=_N								/* **** loop to get 0 in the diagonal elements of DIST Matrix **** */
while `i' <=`nobs'{
	local j=1
	while `j' <=`nobs'{
		if `i'==`j' {
		matrix DIST[`i',`j']=0
				}
		local j=`j'+1 	
		}

local i=`i'+1
}								
restore

****************

gen id= _n
keep id

************************************
******** Defining Matrices *********
************************************

svmat DIST
spmat dta W DIST*, normalize(row) id(id)  replace

***********************************************************
***********************************************************
*** Robustness Test - MinMax Normalization TABLE 7		***
***********************************************************

*spmat dta W DIST*, normalize(minmax) id(id)  replace 

***********************************************************
***********************************************************

spmat getmatrix W WMAT
mata{
st_matrix("DIST", WMAT)
}
preserve
drop _all
svmat DIST
save W.dta, replace 
spatwmat using W.dta, name (WSPATIAL)
restore
drop DIST*


****************************************************
****************************************************
***												****
***  		Identification Strategy	 			****
***												****
****************************************************
****************************************************


use spatialfish_small.dta, clear

************
gen id= _n
************

*****************************************************************
*****			Defining Compliance Variable       		   ******
*****************************************************************

gen compliance = all_mean
*gen compliance = behavior
*gen compliance = intention

****************************************************************


****************************************************************
*****	  		Generating Spatial Lags of X 	       	  ******
****************************************************************


spmat lag x_gdp W gdp
spmat lag x_distance W distance
spmat lag x_gov W gov
spmat lag x_competition W competition
spmat lag x_export W export
spmat lag x_eezcatch W eezcatch
spmat lag x_bio W bio
spmat lag x_ggatt W ggatt
spmat lag x_eu W eu_dum
spmat lag x_treaty W treaty

*****************************************************

******************************************************************
*****	  			0. Step: Defining Control	  	        ******
******************************************************************

local controls   gdp distance gov competition bio  export eezcatch treaty 

****************************************************************
****************************************************************
*** 			Robustness Test  - TABLE 5 				 	 ***
****************************************************************
****************************************************************

*local controls   gdp distance gov competition bio  export eezcatch treaty eu_dum /* Robustness Test - TABLE 5 - Additional Variable: EU */
*local controls   gdp distance gov competition bio  export eezcatch treaty ggatt /* Robustness Test - TABLE 5 - Additional Variable: WTO */
****************************************************************


local spatcontrols   x_gdp x_distance x_gov x_competition x_bio x_export x_eezcatch x_treaty 

****************************************************************
****************************************************************
*** 			Robustness Test  - TABLE 5 				 	 ***
****************************************************************
****************************************************************

*local spatcontrols   x_gdp x_distance x_gov x_competition x_bio x_export x_eezcatch x_treaty x_eu /* Robustness Test - TABLE 5 - Additional Variable: EU */ 
*local spatcontrols   x_gdp x_distance x_gov x_competition x_bio x_export x_eezcatch x_treaty x_ggatt /* Robustness Test - TABLE 5 - Additional Variable: WTO */
****************************************************************

*****************************************************************
*****			1.Step: OLS and Spat Diagnostics       	   ******
*****************************************************************

reg compliance `controls' , r noconst
estimates store ols

spatdiag, weights(WSPATIAL)

spatgsa compliance `controls', weights(WSPATIAL) moran geary  twotail 

*****************************************************************
*****			1.1.Step: Reduced Form Model	       	   ******
***** 					 TABLE 3						   ******
*****************************************************************

#delimit;
reg compliance `controls' `spatcontrols',  noconst;
sca llreg=e(ll);
#delimit cr
estimates store reduced_form


*****************************************************
*****	2.Step: Spatial Durbin Model 	       ******
*****				TABLE 2					   ******
*****************************************************

spreg ml compliance `controls' `spatcontrols', id(id) dlmat(W) noconst
sca lldurb=e(ll)
predict yhat, rform

estimates store durbin

*** lr Test SDM SLX ***
sca llregdurb=2*(lldurb-llreg)
sca lis llregdurb
sca lis llreg

*** Normality Test ***
gen resid=compliance-yhat   /* Residual predicted with reduced form predicter; Limited info predictore of Kelijian 2007 also a possibility
							 ... takes the W*Y combination also into account */
sum resid, d				/* First check on distribution - skewness and kurtosis. Skewness 0 ... non skewed; Kurtosis ... normal distribution around 3 */
swilk resid					/* Both tests are normality tests based on skewness and kurtosis. Swilk = Shapiro-Wilk W Test */
sktest resid
mvtest norm resid			/* significant Doornik Hansen Test means no normality ... numerical test not very powerful in small samples */
qnorm resid					/* Therefore graphical analysis A normal quantile plot graphs the quantiles of a variable against the quantiles of a normal (Gaussian) distribution. 
								qnorm is sensitive to non-normality near the tails*/
pnorm resid					/* pnorm is sensitive to deviations from normality nearer to the center of the distribution */


drop yhat
drop resid

*****************************************************
***** 3.Step: Spatial Lag Model and LR Test    ******
*****************************************************

spreg ml compliance `controls', id(id) dlmat(W) noconst

estimates store lag

lrtest durbin lag 										/*if significant Durbin Model better than Lag model */
sca durbinlag_p=r(p)
sca durbinlag_df=r(df)
sca durbinlag_chi2=r(chi2)


*****************************************************
***** 4.Step: Spatial Error Model and LR Test  ******
*****************************************************

spreg ml compliance `controls' , id(id) elmat(W) noconst

estimates store error

lrtest durbin error 									/*if significant Durbin Model better than Error model */
sca durbinerror_p=r(p)
sca durbinerror_df=r(df)
sca durbinerror_chi2=r(chi2)


*****************************************************
*****	  		Estout Section			  	   ******
*****************************************************

estout ols reduced_form durbin lag error using Spatial_CoC_outcomes.csv, replace starlevels(* 0.10 ** 0.05 *** 0.01) delimiter(;) indicate(`indic') ///
 cells( b(fmt(%09.3fc) star) se(par(`"="("' `")""') fmt(%9.3f)) ) stats( ll chi2 N_g N, star() ///
 fmt( %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f ) labels( "Log likelihood" "Wald chi squared" "Groups" "Number of Observations" ) )

sca lis 


********************************************************
*****	Additional Step: 2SLS Spatial Durbin Model *****
*****				TABLE 3						   *****
********************************************************

spreg gs2sls compliance `controls' `spatcontrols', id(id) dlmat(W) impower(3) noconst


********************************************************
********************************************************
********************************************************

*******************************************************
******** 	Robustness Test TABLE 4			   ********	 
******** 	  	MPA Indicator	  	   		   ********
*******************************************************


use spatialfish_large.dta, clear

****************************************************************

drop if mpa_before==. & mpa_after==.
replace mpa_before=0 if mpa_before==.
replace mpa_after=0 if mpa_after==.

************************************
keep countrycode

rename countrycode iso_d
sort iso_d
save dist_count_merge_isod.dta, replace

******		LAST SORT 		********
rename iso_d iso_o
sort iso_o
save dist_count_merge_isoo.dta, replace

************************************

merge iso_o using dist_cepii.dta
drop if _merge==2
drop _merge

sort iso_d
merge iso_d using dist_count_merge_isod.dta
tab _merge
drop if _merge==1

sort iso_o 
keep  iso_o iso_d dist
sort iso_o iso_d
reshape wide dist, i(iso_o) j(iso_d) string

preserve
#delimit
foreach z of varlist dist* {;
 replace `z'=`z'/1000;
 replace `z'=1/exp(3*`z');			/* exponential distance  */
};
#delimit cr


#delimit;
mkmat  dist*, matrix(DIST) rownames(iso_o);
#delimit cr

local i=1
local nobs=_N								/* **** loop to get 0 in the diagonal elements of DIST Matrix **** */
while `i' <=`nobs'{
	local j=1
	while `j' <=`nobs'{
		if `i'==`j' {
		matrix DIST[`i',`j']=0
				}
		local j=`j'+1 	
		}

local i=`i'+1
}								
restore

****************

gen id= _n
keep id

************************************
******** Defining Matrices *********
************************************

svmat DIST
spmat dta W DIST*, normalize(row) id(id)  replace

spmat getmatrix W WMAT
mata{
st_matrix("DIST", WMAT)
}
preserve
drop _all
svmat DIST
save W.dta, replace 
spatwmat using W.dta, name (WSPATIAL)
restore
drop DIST*


****************************************************
***  				Estimation	 				****
****************************************************


use spatialfish_large.dta, clear

****************************************************************

drop if mpa_before==. & mpa_after==.
replace mpa_before=0 if mpa_before==.
replace mpa_after=0 if mpa_after==.

************
gen id= _n
************

*****************************************************************
*****			Defining Compliance Variable       		   ******
*****************************************************************

replace mpa_before= mpa_before/(gpop_total*1000)
replace mpa_after= mpa_after/(gpop_total*1000)

gen compliance = mpa_after
*gen diff=mpa_after-mpa_before
*gen compliance = diff

****************************************************************


****************************************************************
*****	  		Generating Spatial Lags of X 	       	  ******
****************************************************************


spmat lag x_gdp W gdp
spmat lag x_distance W distance
spmat lag x_gov W gov
spmat lag x_competition W competition
spmat lag x_export W export
spmat lag x_eezcatch W eezcatch
spmat lag x_bio W bio
spmat lag x_treaty W treaty

*****************************************************

******************************************************************
*****	  			0. Step: Defining Control	  	        ******
******************************************************************

local controls   gdp distance gov competition bio  export eezcatch treaty 

local spatcontrols   x_gdp x_distance x_gov x_competition x_bio x_export x_eezcatch x_treaty 


*****************************************************************
*****			1.Step: OLS and Spat Diagnostics       	   ******
*****************************************************************

reg compliance `controls' , r noconst
estimates store ols

spatdiag, weights(WSPATIAL)

spatgsa compliance `controls', weights(WSPATIAL) moran geary  twotail 


*****************************************************
*****	2.Step: Spatial Durbin Model 	       ******
*****		TABLE 4 -MPA Measure			   ******
*****************************************************

spreg ml compliance `controls' `spatcontrols', id(id) dlmat(W) noconst
sca lldurb=e(ll)
predict yhat, rform

estimates store durbin

*** lr Test SDM SLX ***
sca llregdurb=2*(lldurb-llreg)
sca lis llregdurb
sca lis llreg

*** Normality Test ***
gen resid=compliance-yhat   /* Residual predicted with reduced form predicter; Limited info predictore of Kelijian 2007 also a possibility
							 ... takes the W*Y combination also into account */
sum resid, d				/* First check on distribution - skewness and kurtosis. Skewness 0 ... non skewed; Kurtosis ... normal distribution around 3 */
swilk resid					/* Both tests are normality tests based on skewness and kurtosis. Swilk = Shapiro-Wilk W Test */
sktest resid
mvtest norm resid			/* significant Doornik Hansen Test means no normality ... numerical test not very powerful in small samples */
qnorm resid					/* Therefore graphical analysis A normal quantile plot graphs the quantiles of a variable against the quantiles of a normal (Gaussian) distribution. 
								qnorm is sensitive to non-normality near the tails*/
pnorm resid					/* pnorm is sensitive to deviations from normality nearer to the center of the distribution */


drop yhat
drop resid

*****************************************************
***** 3.Step: Spatial Lag Model and LR Test    ******
*****************************************************

spreg ml compliance `controls', id(id) dlmat(W) noconst

estimates store lag

lrtest durbin lag 										/*if significant Durbin Model better than Lag model */
sca durbinlag_p=r(p)
sca durbinlag_df=r(df)
sca durbinlag_chi2=r(chi2)


*****************************************************
***** 4.Step: Spatial Error Model and LR Test  ******
*****************************************************

spreg ml compliance `controls' , id(id) elmat(W) noconst

estimates store error

lrtest durbin error 									/*if significant Durbin Model better than Error model */
sca durbinerror_p=r(p)
sca durbinerror_df=r(df)
sca durbinerror_chi2=r(chi2)



*******************************************************
*******************************************************
******** 	Robustness Test TABLE 4			   ********	 
******** 	  	TROPHY Indicator  	   		   ********
*******************************************************
*******************************************************


use spatialfish_large.dta, clear

drop if countrycode=="GMB" | countrycode=="ROM" | countrycode=="YUG"

****************************************************************

************************************
keep countrycode

rename countrycode iso_d
sort iso_d
save dist_count_merge_isod.dta, replace

******		LAST SORT 		********
rename iso_d iso_o
sort iso_o
save dist_count_merge_isoo.dta, replace

************************************

merge iso_o using dist_cepii.dta
drop if _merge==2
drop _merge

sort iso_d
merge iso_d using dist_count_merge_isod.dta
tab _merge
drop if _merge==1

sort iso_o 
keep  iso_o iso_d dist
sort iso_o iso_d
reshape wide dist, i(iso_o) j(iso_d) string

preserve
#delimit
foreach z of varlist dist* {;
 replace `z'=`z'/1000;
 replace `z'=1/exp(3*`z');			/* exponential distance  */
};
#delimit cr


#delimit;
mkmat  dist*, matrix(DIST) rownames(iso_o);
#delimit cr

local i=1
local nobs=_N								/* **** loop to get 0 in the diagonal elements of DIST Matrix **** */
while `i' <=`nobs'{
	local j=1
	while `j' <=`nobs'{
		if `i'==`j' {
		matrix DIST[`i',`j']=0
				}
		local j=`j'+1 	
		}

local i=`i'+1
}								
restore

****************

gen id= _n
keep id

************************************
******** Defining Matrices *********
************************************

svmat DIST
spmat dta W DIST*, normalize(row) id(id)  replace

spmat getmatrix W WMAT
mata{
st_matrix("DIST", WMAT)
}
preserve
drop _all
svmat DIST
save W.dta, replace 
spatwmat using W.dta, name (WSPATIAL)
restore
drop DIST*


****************************************************
***  				Estimation		 			****
****************************************************


use spatialfish_large.dta, clear


drop if countrycode=="GMB" | countrycode=="ROM" | countrycode=="YUG"

************
gen id= _n
************

*****************************************************************
*****			Defining Compliance Variable       		   ******
*****************************************************************

gen compliance = trophic_after
*gen diff=trophic_after-trophic_before
*gen compliance = diff

****************************************************************


****************************************************************
*****	  		Generating Spatial Lags of X 	       	  ******
****************************************************************


spmat lag x_gdp W gdp
spmat lag x_distance W distance
spmat lag x_gov W gov
spmat lag x_competition W competition
spmat lag x_export W export
spmat lag x_eezcatch W eezcatch
spmat lag x_bio W bio
spmat lag x_treaty W treaty

*****************************************************

******************************************************************
*****	  			0. Step: Defining Control	  	        ******
******************************************************************

local controls   gdp distance gov competition bio  export eezcatch treaty 

local spatcontrols   x_gdp x_distance x_gov x_competition x_bio x_export x_eezcatch x_treaty 


*****************************************************************
*****			1.Step: OLS and Spat Diagnostics       	   ******
*****************************************************************

reg compliance `controls' , r noconst
estimates store ols

spatdiag, weights(WSPATIAL)

spatgsa compliance `controls', weights(WSPATIAL) moran geary  twotail 


*****************************************************
*****		 	Spatial Durbin Model 	       ******
*****		TABLE 4 - Trophy Indicator		   ******
*****************************************************

spreg ml compliance `controls' `spatcontrols', id(id) dlmat(W) noconst
sca lldurb=e(ll)
predict yhat, rform

estimates store durbin

*** lr Test SDM SLX ***
sca llregdurb=2*(lldurb-llreg)
sca lis llregdurb
sca lis llreg

*** Normality Test ***
gen resid=compliance-yhat   /* Residual predicted with reduced form predicter; Limited info predictore of Kelijian 2007 also a possibility
							 ... takes the W*Y combination also into account */
sum resid, d				/* First check on distribution - skewness and kurtosis. Skewness 0 ... non skewed; Kurtosis ... normal distribution around 3 */
swilk resid					/* Both tests are normality tests based on skewness and kurtosis. Swilk = Shapiro-Wilk W Test */
sktest resid
mvtest norm resid			/* significant Doornik Hansen Test means no normality ... numerical test not very powerful in small samples */
qnorm resid					/* Therefore graphical analysis A normal quantile plot graphs the quantiles of a variable against the quantiles of a normal (Gaussian) distribution. 
								qnorm is sensitive to non-normality near the tails*/
pnorm resid					/* pnorm is sensitive to deviations from normality nearer to the center of the distribution */


drop yhat
drop resid

*****************************************************
***** 3.Step: Spatial Lag Model and LR Test    ******
*****************************************************

spreg ml compliance `controls', id(id) dlmat(W) noconst

estimates store lag

lrtest durbin lag 										/*if significant Durbin Model better than Lag model */
sca durbinlag_p=r(p)
sca durbinlag_df=r(df)
sca durbinlag_chi2=r(chi2)


*****************************************************
***** 4.Step: Spatial Error Model and LR Test  ******
*****************************************************

spreg ml compliance `controls' , id(id) elmat(W) noconst

estimates store error

lrtest durbin error 									/*if significant Durbin Model better than Error model */
sca durbinerror_p=r(p)
sca durbinerror_df=r(df)
sca durbinerror_chi2=r(chi2)


*******************************************************
*******************************************************
******** 	Robustness Test TABLE 6			   ********	 
******** 	  Political Distance  	   		   ********
*******************************************************
*******************************************************

*********************************************
*** 		Spatial Weights 			  ***
*********************************************

use spatialfish_small.dta, clear
sca drop _all

**********************************************

merge 1:m countrycode using treaty_all_final.dta
drop if _merge==2

keep  countrycode treatnr treatname treatplace treatyear
drop if  treatyear>2005
keep countrycode treatnr

gen treatdum=1 if treatnr!=0
egen countnumb=group(treatnr)
replace treatnr = countnumb
drop countnumb
reshape wide treatdum, i(countrycode) j(treatnr)

#delimit;
foreach z of varlist treatdum* {;
quietly replace `z'=0 if `z'==.;
};
#delimit cr

#delimit;
egen treatsum=rowtotal(treatdum*);
#delimit cr

sort countrycode							/* *** LAST SORT!!! *** */

local nobs= _N
mat TREAT=J(`nobs',`nobs',0)				

local i=1									/* **** Define weights for each element in matrix TREAT **** */
while `i' <=`nobs'{
	
	local j=1
	while `j' <=`nobs'{
			sca wm=0
#delimit;
foreach z of varlist treatdum*	{;
			sca wm=wm+(`z'[`i']*`z'[`j']);
			#delimit cr
			}
		if `i'==`j' {
		matrix TREAT[`i',`j']=0
				}
		if `i'~=`j' {
		matrix TREAT[`i',`j']=wm
			}
		sca drop wm
		local j=`j'+1 	
		}

local i=`i'+1
}									

****

mkmat treatsum, matrix(TREATSUM)
mat ii=J(`nobs',1,1)  
mat T=ii'
mat Z=TREATSUM*T

****

mat TREATREL=J(`nobs',`nobs',0)						
local i=1											/* **** Divide shared treaties by treatsum - generating relative amount of shared treaties for each country**** */
while `i' <=`nobs'{
	
	local j=1
	while `j' <=`nobs'{
		if `i'==`j' {
		matrix TREATREL[`i',`j']=0
				}
		if `i'~=`j' {
		matrix TREATREL[`i',`j']=TREAT[`i',`j']/443
			}
		local j=`j'+1 	
		}

local i=`i'+1
}									
**********************************************
**********************************************

keep countrycode

rename countrycode iso_d
sort iso_d
save dist_count_merge_isod.dta, replace

******		LAST SORT 		********
rename iso_d iso_o
sort iso_o
save dist_count_merge_isoo.dta, replace

************************************


*********ready to merge*************
merge iso_o using dist_cepii.dta
drop if _merge==2
drop _merge

sort iso_d
merge iso_d using dist_count_merge_isod.dta
tab _merge
drop if _merge==1

sort iso_o 
keep  iso_o iso_d dist
sort iso_o iso_d
reshape wide dist, i(iso_o) j(iso_d) string

preserve
#delimit
foreach z of varlist dist* {;
 replace `z'=`z'/1000;
 replace `z'=1/exp(3*`z');			
};
#delimit cr


#delimit;
mkmat  dist*, matrix(DIST) rownames(iso_o);
#delimit cr

local i=1
local nobs=_N								/* **** loop to get 0 in the diagonal elements of DIST Matrix **** */
while `i' <=`nobs'{
	
	local j=1
	while `j' <=`nobs'{
		if `i'==`j' {
		matrix DIST[`i',`j']=0
				}
		local j=`j'+1 	
		}

local i=`i'+1
}								
restore
****

mat TREATRELDIST=J(`nobs',`nobs',0)			/* **** Matrix 51*51 with 0 **** */
local i=1									/* **** loops to multiply elements of TREATREL and DISTI Matrix - generating weighted relative distance matrix for all countries **** */
while `i' <=`nobs'{
	
	local j=1
	while `j' <=`nobs'{
		if `i'==`j' {
		matrix TREATRELDIST[`i',`j']=0
				}
		if `i'~=`j' {
		matrix TREATRELDIST[`i',`j']=TREATREL[`i',`j']*DIST[`i',`j']
			}
		local j=`j'+1 	
		}

local i=`i'+1
}					

****************

gen id= _n
keep id


************************************
***   Defining PolDist Matrices  ***
************************************

svmat TREATRELDIST
spmat dta W TREAT*, normalize(row) id(id)  replace
spmat getmatrix W WMAT
mata{
st_matrix("TREAT", WMAT)
}
preserve
drop _all
svmat TREAT
save W.dta, replace 
spatwmat using W.dta, name (WSPATIAL)
restore
drop TREAT*

*****

****************************************************
***  			Estimation	 					****
****************************************************

use spatialfish_small.dta, clear

************
gen id= _n
************

*****************************************************************
*****			Defining Compliance Variable       		   ******
*****************************************************************

gen compliance = all_mean

****************************************************************
*****	  		Generating Spatial Lags of X 	       	  ******
****************************************************************

spmat lag x_gdp W gdp
spmat lag x_distance W distance
spmat lag x_gov W gov
spmat lag x_competition W competition
spmat lag x_export W export
spmat lag x_eezcatch W eezcatch
spmat lag x_bio W bio
spmat lag x_treaty W treaty

*****************************************************

******************************************************************
*****	  			 Defining Control	  	        		******
******************************************************************

local controls   gdp distance gov competition bio  export eezcatch treaty 
local spatcontrols   x_gdp x_distance x_gov x_competition x_bio x_export x_eezcatch x_treaty 

*****************************************************************
*****			 	OLS and Spat Diagnostics	       	   ******
*****************************************************************

reg compliance `controls' , r noconst
estimates store ols

spatdiag, weights(WSPATIAL)

spatgsa compliance `controls', weights(WSPATIAL) moran geary  twotail 

*****************************************************
*****		  	Spatial Durbin Model 	       ******
***** 		Political Distance TABLE 6		   ******
*****************************************************

spreg ml compliance `controls' `spatcontrols', id(id) dlmat(W) noconst

sca lldurb=e(ll)
predict yhat, rform

estimates store durbin

*** lr Test SDM SLX ***
sca llregdurb=2*(lldurb-llreg)
sca lis llregdurb
sca lis llreg

*** Normality Test ***
gen resid=compliance-yhat   /* Residual predicted with reduced form predicter; Limited info predictore of Kelijian 2007 also a possibility
							 ... takes the W*Y combination also into account */
sum resid, d				/* First check on distribution - skewness and kurtosis. Skewness 0 ... non skewed; Kurtosis ... normal distribution around 3 */
swilk resid					/* Both tests are normality tests based on skewness and kurtosis. Swilk = Shapiro-Wilk W Test */
sktest resid
mvtest norm resid			/* significant Doornik Hansen Test means no normality ... numerical test not very powerful in small samples */
qnorm resid					/* Therefore graphical analysis A normal quantile plot graphs the quantiles of a variable against the quantiles of a normal (Gaussian) distribution. 
								qnorm is sensitive to non-normality near the tails*/
pnorm resid					/* pnorm is sensitive to deviations from normality nearer to the center of the distribution */


drop yhat
drop resid

*****************************************************
*****  	 Spatial Lag Model and LR Test    	   ******
*****************************************************

spreg ml compliance `controls', id(id) dlmat(W) noconst

estimates store lag

lrtest durbin lag 										/*if significant Durbin Model better than Lag model */
sca durbinlag_p=r(p)
sca durbinlag_df=r(df)
sca durbinlag_chi2=r(chi2)


*****************************************************
*****    Spatial Error Model and LR Test 	   ******
*****************************************************

spreg ml compliance `controls' , id(id) elmat(W) noconst

estimates store error

lrtest durbin error 									/*if significant Durbin Model better than Error model */
sca durbinerror_p=r(p)
sca durbinerror_df=r(df)
sca durbinerror_chi2=r(chi2)


*******************************************************
*******************************************************
******** 	Robustness Test TABLE 6			   ********	 
******** 	  Nearest Neighbor  	   		   ********
*******************************************************
*******************************************************

use spatialfish_small.dta, clear

keep countrycode

rename countrycode iso_d
sort iso_d
save dist_count_merge_isod.dta, replace

******		LAST SORT 		********
rename iso_d iso_o
sort iso_o
save dist_count_merge_isoo.dta, replace

************************************

*********ready to merge*************
merge iso_o using dist_cepii.dta
drop if _merge==2
drop _merge

sort iso_d
merge iso_d using dist_count_merge_isod.dta
tab _merge
drop if _merge==1

sort iso_o 
keep  iso_o iso_d dist
sort iso_o iso_d
reshape wide dist, i(iso_o) j(iso_d) string


preserve
mkmat  dist*, matrix(DIST) rownames(iso_o)

local i=1
local nobs=_N								/* **** loop to get 0 in the diagonal elements of DIST Matrix **** */
while `i' <=`nobs'{
	
	local j=1
	while `j' <=`nobs'{
		if `i'==`j' {
		matrix DIST[`i',`j']=0
				}
		local j=`j'+1 	
		}

local i=`i'+1
}								
restore


#delimit;
mkmat  dist*, matrix(DISTNN) rownames(iso_o);
#delimit cr
local i=1
local nobs=_N								/* **** loop to get 0 in the diagonal elements of DISTNN Matrix **** */
while `i' <=`nobs'{
	
	local j=1
	while `j' <=`nobs'{
		if `i'==`j' {
		matrix DISTNN[`i',`j']=0
				}
		local j=`j'+1 	
		}

local i=`i'+1
}	

svmat DISTNN
foreach z of varlist DISTNN* {
replace `z'=. if `z'==0
}
egen rowmin = rowmin(DISTNN*)
egen rowminmax=max(rowmin)
sca nndist=rowminmax

#delimit
foreach z of varlist DISTNN* {;
 replace `z'=0 if `z'>nndist;
 replace `z'=`z'/1000;
 replace `z'=1/exp(3*`z') if `z'!=0;		/* exponential distance  */

};
#delimit cr

#delimit;
mkmat DISTNN*, matrix(DISTNNN) rownames(iso_o);
#delimit cr

local i=1
local nobs=_N								/* **** loop to get 0 in the diagonal elements of DISTNN Matrix **** */
while `i' <=`nobs'{
	
	local j=1
	while `j' <=`nobs'{
		if `i'==`j' {
		matrix DISTNNN[`i',`j']=0
				}
		local j=`j'+1 	
		}

local i=`i'+1
}	


**********************************************

gen id= _n
keep id

************************************
******** Defining Matrices *********
******** Nearest Neighbour *********
************************************

svmat DISTNNN
spmat dta W DISTNNN*, normalize(min) id(id)  replace
spmat getmatrix W WMAT
mata{
st_matrix("DISTNNN", WMAT)
}
preserve
drop _all
svmat DISTNNN
save W.dta, replace 
spatwmat using W.dta, name (WSPATIAL)
restore
drop DISTNNN*


****************************************************
***  			Estimation	 					****
****************************************************
use spatialfish_small.dta, clear

****************************************************************

************
gen id= _n
************

*****************************************************************
*****			Defining Compliance Variable       		   ******
*****************************************************************

gen compliance = all_mean

****************************************************************
*****	  		Generating Spatial Lags of X 	       	  ******
****************************************************************


spmat lag x_gdp W gdp
spmat lag x_distance W distance
spmat lag x_gov W gov
spmat lag x_competition W competition
spmat lag x_exportnn W exportnn
spmat lag x_eezcatch W eezcatch
spmat lag x_bio W bio
spmat lag x_treaty W treaty

******************************************************************
*****	  			Defining Control			  	        ******
******************************************************************

local controls   gdp distance gov competition bio  exportnn eezcatch treaty 
local spatcontrols   x_gdp x_distance x_gov x_competition x_bio x_exportnn x_eezcatch x_treaty 


*****************************************************************
*****				OLS and Spat Diagnostics	       	   ******
*****************************************************************

reg compliance `controls' , r noconst
estimates store ols

spatdiag, weights(WSPATIAL)

spatgsa compliance `controls', weights(WSPATIAL) moran geary  twotail 

*****************************************************
*****	 		Spatial Durbin Model 	       ******
***** 		Nearest Neighbour TABLE 6		   ******	 
*****************************************************

spreg ml compliance `controls' `spatcontrols', id(id) dlmat(W) noconst

*****************************************************
sca lldurb=e(ll)
predict yhat, rform

estimates store durbin

*** lr Test SDM SLX ***
sca llregdurb=2*(lldurb-llreg)
sca lis llregdurb
sca lis llreg

*** Normality Test ***
gen resid=compliance-yhat   /* Residual predicted with reduced form predicter; Limited info predictore of Kelijian 2007 also a possibility
							 ... takes the W*Y combination also into account */
sum resid, d				/* First check on distribution - skewness and kurtosis. Skewness 0 ... non skewed; Kurtosis ... normal distribution around 3 */
swilk resid					/* Both tests are normality tests based on skewness and kurtosis. Swilk = Shapiro-Wilk W Test */
sktest resid
mvtest norm resid			/* significant Doornik Hansen Test means no normality ... numerical test not very powerful in small samples */
qnorm resid					/* Therefore graphical analysis A normal quantile plot graphs the quantiles of a variable against the quantiles of a normal (Gaussian) distribution. 
								qnorm is sensitive to non-normality near the tails*/
pnorm resid					/* pnorm is sensitive to deviations from normality nearer to the center of the distribution */


drop yhat
drop resid

*****************************************************
*****  		Spatial Lag Model and LR Test 	   ******
*****************************************************

spreg ml compliance `controls', id(id) dlmat(W) noconst

estimates store lag

lrtest durbin lag 										/*if significant Durbin Model better than Lag model */
sca durbinlag_p=r(p)
sca durbinlag_df=r(df)
sca durbinlag_chi2=r(chi2)


*****************************************************
*****  		Spatial Error Model and LR Test    ******
*****************************************************

spreg ml compliance `controls' , id(id) elmat(W) noconst

estimates store error

lrtest durbin error 									/*if significant Durbin Model better than Error model */
sca durbinerror_p=r(p)
sca durbinerror_df=r(df)
sca durbinerror_chi2=r(chi2)



*********************************************************************
*********************************************************************
*****  							END 							*****
*********************************************************************
*********************************************************************
	


